#[non_exhaustive]pub struct RedactionRules {
pub keep_room_aliases_aliases: bool,
pub keep_room_join_rules_allow: bool,
pub keep_room_member_join_authorised_via_users_server: bool,
pub keep_origin_membership_prev_state: bool,
pub keep_room_create_content: bool,
pub keep_room_redaction_redacts: bool,
pub keep_room_power_levels_invite: bool,
pub keep_room_member_third_party_invite_signed: bool,
pub content_field_redacts: bool,
pub keep_room_server_acl_allow_deny_allow_ip_literals: bool,
}Expand description
The tweaks in the redaction algorithm for a room version.
This type can be constructed from one of its constants (like RedactionRules::V1), or by
constructing a RoomVersionRules first and using the redaction field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.keep_room_aliases_aliases: boolWhether to keep the aliases field in the content of m.room.aliases events (spec),
disabled since room version 6.
keep_room_join_rules_allow: boolWhether to keep the allow field in the content of m.room.join_rules events (spec),
introduced in room version 8.
Whether to keep the join_authorised_via_users_server field in the content of
m.room.member events (spec), introduced in room version 9.
keep_origin_membership_prev_state: boolWhether to keep the origin, membership and prev_state fields a the top-level of all
events (spec), disabled since room version 11.
keep_room_create_content: boolWhether to keep the entire content of m.room.create events (spec), introduced in room
version 11.
keep_room_redaction_redacts: boolWhether to keep the redacts field in the content of m.room.redaction events (spec),
introduced in room version 11.
keep_room_power_levels_invite: boolWhether to keep the invite field in the content of m.room.power_levels events
(spec), introduced in room version 11.
keep_room_member_third_party_invite_signed: boolWhether to keep the signed field in third_party_invite of the content of
m.room.member events (spec), introduced in room version 11.
content_field_redacts: boolWhether the content.redacts field should be used to determine the event an event
redacts, as opposed to the top-level redacts field (spec), introduced in room version
11.
keep_room_server_acl_allow_deny_allow_ip_literals: boolunstable-msc2870 only.Whether to keep the allow, deny and allow_ip_literals in the content of
m.room.server_acl events (MSC2870).
Implementations
Sourceimpl RedactionRules
impl RedactionRules
Sourcepub const V1: RedactionRules
Available on crate feature events only.
pub const V1: RedactionRules
events only.Redaction rules as introduced in room version 1 (spec).
Sourcepub const V6: RedactionRules
Available on crate feature events only.
pub const V6: RedactionRules
events only.Redaction rules with tweaks introduced in room version 6 (spec).
Sourcepub const V8: RedactionRules
Available on crate feature events only.
pub const V8: RedactionRules
events only.Redaction rules with tweaks introduced in room version 8 (spec).
Sourcepub const V9: RedactionRules
Available on crate feature events only.
pub const V9: RedactionRules
events only.Redaction rules with tweaks introduced in room version 9 (spec).
Sourcepub const V11: RedactionRules
Available on crate feature events only.
pub const V11: RedactionRules
events only.Redaction rules with tweaks introduced in room version 11 (spec).
Sourcepub const MSC2870: RedactionRules
Available on crate features events and unstable-msc2870 only.
pub const MSC2870: RedactionRules
events and unstable-msc2870 only.Redaction rules with tweaks introduced in MSC2870.